======================
Command Line Interface
======================

.. code-block:: bash

	cubids --help

This will print the instructions for using the command line interface in your command line.

.. argparse::
   :ref: cubids.cli._get_parser
   :prog: cubids
   :func: _get_parser
